==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkImplicitModeller.java <==
// java wrapper for vtkImplicitModeller object
//

package vtk;
import vtk.*;

public class vtkImplicitModeller extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double ComputeModelBounds_2(vtkDataSet id0);
  public double ComputeModelBounds(vtkDataSet id0)
    { return ComputeModelBounds_2(id0); }

  private native int[]  GetSampleDimensions_3();
  public int[]  GetSampleDimensions()
    { return GetSampleDimensions_3(); }

  private native void SetSampleDimensions_4(int id0,int id1,int id2);
  public void SetSampleDimensions(int id0,int id1,int id2)
    { SetSampleDimensions_4(id0,id1,id2); }

  private native void SetSampleDimensions_5(int id0[]);
  public void SetSampleDimensions(int id0[])
    { SetSampleDimensions_5(id0); }

  private native void SetMaximumDistance_6(double id0);
  public void SetMaximumDistance(double id0)
    { SetMaximumDistance_6(id0); }

  private native double GetMaximumDistanceMinValue_7();
  public double GetMaximumDistanceMinValue()
    { return GetMaximumDistanceMinValue_7(); }

  private native double GetMaximumDistanceMaxValue_8();
  public double GetMaximumDistanceMaxValue()
    { return GetMaximumDistanceMaxValue_8(); }

  private native double GetMaximumDistance_9();
  public double GetMaximumDistance()
    { return GetMaximumDistance_9(); }

  private native void SetModelBounds_10(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetModelBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetModelBounds_10(id0,id1,id2,id3,id4,id5); }

  private native void SetModelBounds_11(double id0[]);
  public void SetModelBounds(double id0[])
    { SetModelBounds_11(id0); }

  private native double[] GetModelBounds_12();
  public double[] GetModelBounds()
    { return GetModelBounds_12(); }

  private native void SetAdjustBounds_13(int id0);
  public void SetAdjustBounds(int id0)
    { SetAdjustBounds_13(id0); }

  private native int GetAdjustBounds_14();
  public int GetAdjustBounds()
    { return GetAdjustBounds_14(); }

  private native void AdjustBoundsOn_15();
  public void AdjustBoundsOn()
    { AdjustBoundsOn_15(); }

  private native void AdjustBoundsOff_16();
  public void AdjustBoundsOff()
    { AdjustBoundsOff_16(); }

  private native void SetAdjustDistance_17(double id0);
  public void SetAdjustDistance(double id0)
    { SetAdjustDistance_17(id0); }

  private native double GetAdjustDistanceMinValue_18();
  public double GetAdjustDistanceMinValue()
    { return GetAdjustDistanceMinValue_18(); }

  private native double GetAdjustDistanceMaxValue_19();
  public double GetAdjustDistanceMaxValue()
    { return GetAdjustDistanceMaxValue_19(); }

  private native double GetAdjustDistance_20();
  public double GetAdjustDistance()
    { return GetAdjustDistance_20(); }

  private native void SetCapping_21(int id0);
  public void SetCapping(int id0)
    { SetCapping_21(id0); }

  private native int GetCapping_22();
  public int GetCapping()
    { return GetCapping_22(); }

  private native void CappingOn_23();
  public void CappingOn()
    { CappingOn_23(); }

  private native void CappingOff_24();
  public void CappingOff()
    { CappingOff_24(); }

  private native void SetCapValue_25(double id0);
  public void SetCapValue(double id0)
    { SetCapValue_25(id0); }

  private native double GetCapValue_26();
  public double GetCapValue()
    { return GetCapValue_26(); }

  private native void SetScaleToMaximumDistance_27(int id0);
  public void SetScaleToMaximumDistance(int id0)
    { SetScaleToMaximumDistance_27(id0); }

  private native int GetScaleToMaximumDistance_28();
  public int GetScaleToMaximumDistance()
    { return GetScaleToMaximumDistance_28(); }

  private native void ScaleToMaximumDistanceOn_29();
  public void ScaleToMaximumDistanceOn()
    { ScaleToMaximumDistanceOn_29(); }

  private native void ScaleToMaximumDistanceOff_30();
  public void ScaleToMaximumDistanceOff()
    { ScaleToMaximumDistanceOff_30(); }

  private native void SetProcessMode_31(int id0);
  public void SetProcessMode(int id0)
    { SetProcessMode_31(id0); }

  private native int GetProcessModeMinValue_32();
  public int GetProcessModeMinValue()
    { return GetProcessModeMinValue_32(); }

  private native int GetProcessModeMaxValue_33();
  public int GetProcessModeMaxValue()
    { return GetProcessModeMaxValue_33(); }

  private native int GetProcessMode_34();
  public int GetProcessMode()
    { return GetProcessMode_34(); }

  private native void SetProcessModeToPerVoxel_35();
  public void SetProcessModeToPerVoxel()
    { SetProcessModeToPerVoxel_35(); }

  private native void SetProcessModeToPerCell_36();
  public void SetProcessModeToPerCell()
    { SetProcessModeToPerCell_36(); }

  private native String GetProcessModeAsString_37();
  public String GetProcessModeAsString()
    { return GetProcessModeAsString_37(); }

  private native void SetLocatorMaxLevel_38(int id0);
  public void SetLocatorMaxLevel(int id0)
    { SetLocatorMaxLevel_38(id0); }

  private native int GetLocatorMaxLevel_39();
  public int GetLocatorMaxLevel()
    { return GetLocatorMaxLevel_39(); }

  private native void SetNumberOfThreads_40(int id0);
  public void SetNumberOfThreads(int id0)
    { SetNumberOfThreads_40(id0); }

  private native int GetNumberOfThreadsMinValue_41();
  public int GetNumberOfThreadsMinValue()
    { return GetNumberOfThreadsMinValue_41(); }

  private native int GetNumberOfThreadsMaxValue_42();
  public int GetNumberOfThreadsMaxValue()
    { return GetNumberOfThreadsMaxValue_42(); }

  private native int GetNumberOfThreads_43();
  public int GetNumberOfThreads()
    { return GetNumberOfThreads_43(); }

  private native void SetOutputScalarType_44(int id0);
  public void SetOutputScalarType(int id0)
    { SetOutputScalarType_44(id0); }

  private native int GetOutputScalarType_45();
  public int GetOutputScalarType()
    { return GetOutputScalarType_45(); }

  private native void SetOutputScalarTypeToFloat_46();
  public void SetOutputScalarTypeToFloat()
    { SetOutputScalarTypeToFloat_46(); }

  private native void SetOutputScalarTypeToDouble_47();
  public void SetOutputScalarTypeToDouble()
    { SetOutputScalarTypeToDouble_47(); }

  private native void SetOutputScalarTypeToInt_48();
  public void SetOutputScalarTypeToInt()
    { SetOutputScalarTypeToInt_48(); }

  private native void SetOutputScalarTypeToUnsignedInt_49();
  public void SetOutputScalarTypeToUnsignedInt()
    { SetOutputScalarTypeToUnsignedInt_49(); }

  private native void SetOutputScalarTypeToLong_50();
  public void SetOutputScalarTypeToLong()
    { SetOutputScalarTypeToLong_50(); }

  private native void SetOutputScalarTypeToUnsignedLong_51();
  public void SetOutputScalarTypeToUnsignedLong()
    { SetOutputScalarTypeToUnsignedLong_51(); }

  private native void SetOutputScalarTypeToShort_52();
  public void SetOutputScalarTypeToShort()
    { SetOutputScalarTypeToShort_52(); }

  private native void SetOutputScalarTypeToUnsignedShort_53();
  public void SetOutputScalarTypeToUnsignedShort()
    { SetOutputScalarTypeToUnsignedShort_53(); }

  private native void SetOutputScalarTypeToUnsignedChar_54();
  public void SetOutputScalarTypeToUnsignedChar()
    { SetOutputScalarTypeToUnsignedChar_54(); }

  private native void SetOutputScalarTypeToChar_55();
  public void SetOutputScalarTypeToChar()
    { SetOutputScalarTypeToChar_55(); }

  private native void StartAppend_56();
  public void StartAppend()
    { StartAppend_56(); }

  private native void Append_57(vtkDataSet id0);
  public void Append(vtkDataSet id0)
    { Append_57(id0); }

  private native void EndAppend_58();
  public void EndAppend()
    { EndAppend_58(); }

  public vtkImplicitModeller() { super(); }

  public vtkImplicitModeller(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-5-aarch64.pkg.tar.xz: vtk/vtkImplicitModeller.java <==
// java wrapper for vtkImplicitModeller object
//

package vtk;
import vtk.*;

public class vtkImplicitModeller extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double ComputeModelBounds_2(vtkDataSet id0);
  public double ComputeModelBounds(vtkDataSet id0)
    { return ComputeModelBounds_2(id0); }

  private native int[]  GetSampleDimensions_3();
  public int[]  GetSampleDimensions()
    { return GetSampleDimensions_3(); }

  private native void SetSampleDimensions_4(int id0,int id1,int id2);
  public void SetSampleDimensions(int id0,int id1,int id2)
    { SetSampleDimensions_4(id0,id1,id2); }

  private native void SetSampleDimensions_5(int id0[]);
  public void SetSampleDimensions(int id0[])
    { SetSampleDimensions_5(id0); }

  private native void SetMaximumDistance_6(double id0);
  public void SetMaximumDistance(double id0)
    { SetMaximumDistance_6(id0); }

  private native double GetMaximumDistanceMinValue_7();
  public double GetMaximumDistanceMinValue()
    { return GetMaximumDistanceMinValue_7(); }

  private native double GetMaximumDistanceMaxValue_8();
  public double GetMaximumDistanceMaxValue()
    { return GetMaximumDistanceMaxValue_8(); }

  private native double GetMaximumDistance_9();
  public double GetMaximumDistance()
    { return GetMaximumDistance_9(); }

  private native void SetModelBounds_10(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetModelBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetModelBounds_10(id0,id1,id2,id3,id4,id5); }

  private native void SetModelBounds_11(double id0[]);
  public void SetModelBounds(double id0[])
    { SetModelBounds_11(id0); }

  private native double[] GetModelBounds_12();
  public double[] GetModelBounds()
    { return GetModelBounds_12(); }

  private native void SetAdjustBounds_13(int id0);
  public void SetAdjustBounds(int id0)
    { SetAdjustBounds_13(id0); }

  private native int GetAdjustBounds_14();
  public int GetAdjustBounds()
    { return GetAdjustBounds_14(); }

  private native void AdjustBoundsOn_15();
  public void AdjustBoundsOn()
    { AdjustBoundsOn_15(); }

  private native void AdjustBoundsOff_16();
  public void AdjustBoundsOff()
    { AdjustBoundsOff_16(); }

  private native void SetAdjustDistance_17(double id0);
  public void SetAdjustDistance(double id0)
    { SetAdjustDistance_17(id0); }

  private native double GetAdjustDistanceMinValue_18();
  public double GetAdjustDistanceMinValue()
    { return GetAdjustDistanceMinValue_18(); }

  private native double GetAdjustDistanceMaxValue_19();
  public double GetAdjustDistanceMaxValue()
    { return GetAdjustDistanceMaxValue_19(); }

  private native double GetAdjustDistance_20();
  public double GetAdjustDistance()
    { return GetAdjustDistance_20(); }

  private native void SetCapping_21(int id0);
  public void SetCapping(int id0)
    { SetCapping_21(id0); }

  private native int GetCapping_22();
  public int GetCapping()
    { return GetCapping_22(); }

  private native void CappingOn_23();
  public void CappingOn()
    { CappingOn_23(); }

  private native void CappingOff_24();
  public void CappingOff()
    { CappingOff_24(); }

  private native void SetCapValue_25(double id0);
  public void SetCapValue(double id0)
    { SetCapValue_25(id0); }

  private native double GetCapValue_26();
  public double GetCapValue()
    { return GetCapValue_26(); }

  private native void SetScaleToMaximumDistance_27(int id0);
  public void SetScaleToMaximumDistance(int id0)
    { SetScaleToMaximumDistance_27(id0); }

  private native int GetScaleToMaximumDistance_28();
  public int GetScaleToMaximumDistance()
    { return GetScaleToMaximumDistance_28(); }

  private native void ScaleToMaximumDistanceOn_29();
  public void ScaleToMaximumDistanceOn()
    { ScaleToMaximumDistanceOn_29(); }

  private native void ScaleToMaximumDistanceOff_30();
  public void ScaleToMaximumDistanceOff()
    { ScaleToMaximumDistanceOff_30(); }

  private native void SetProcessMode_31(int id0);
  public void SetProcessMode(int id0)
    { SetProcessMode_31(id0); }

  private native int GetProcessModeMinValue_32();
  public int GetProcessModeMinValue()
    { return GetProcessModeMinValue_32(); }

  private native int GetProcessModeMaxValue_33();
  public int GetProcessModeMaxValue()
    { return GetProcessModeMaxValue_33(); }

  private native int GetProcessMode_34();
  public int GetProcessMode()
    { return GetProcessMode_34(); }

  private native void SetProcessModeToPerVoxel_35();
  public void SetProcessModeToPerVoxel()
    { SetProcessModeToPerVoxel_35(); }

  private native void SetProcessModeToPerCell_36();
  public void SetProcessModeToPerCell()
    { SetProcessModeToPerCell_36(); }

  private native String GetProcessModeAsString_37();
  public String GetProcessModeAsString()
    { return GetProcessModeAsString_37(); }

  private native void SetLocatorMaxLevel_38(int id0);
  public void SetLocatorMaxLevel(int id0)
    { SetLocatorMaxLevel_38(id0); }

  private native int GetLocatorMaxLevel_39();
  public int GetLocatorMaxLevel()
    { return GetLocatorMaxLevel_39(); }

  private native void SetNumberOfThreads_40(int id0);
  public void SetNumberOfThreads(int id0)
    { SetNumberOfThreads_40(id0); }

  private native int GetNumberOfThreadsMinValue_41();
  public int GetNumberOfThreadsMinValue()
    { return GetNumberOfThreadsMinValue_41(); }

  private native int GetNumberOfThreadsMaxValue_42();
  public int GetNumberOfThreadsMaxValue()
    { return GetNumberOfThreadsMaxValue_42(); }

  private native int GetNumberOfThreads_43();
  public int GetNumberOfThreads()
    { return GetNumberOfThreads_43(); }

  private native void SetOutputScalarType_44(int id0);
  public void SetOutputScalarType(int id0)
    { SetOutputScalarType_44(id0); }

  private native int GetOutputScalarType_45();
  public int GetOutputScalarType()
    { return GetOutputScalarType_45(); }

  private native void SetOutputScalarTypeToFloat_46();
  public void SetOutputScalarTypeToFloat()
    { SetOutputScalarTypeToFloat_46(); }

  private native void SetOutputScalarTypeToDouble_47();
  public void SetOutputScalarTypeToDouble()
    { SetOutputScalarTypeToDouble_47(); }

  private native void SetOutputScalarTypeToInt_48();
  public void SetOutputScalarTypeToInt()
    { SetOutputScalarTypeToInt_48(); }

  private native void SetOutputScalarTypeToUnsignedInt_49();
  public void SetOutputScalarTypeToUnsignedInt()
    { SetOutputScalarTypeToUnsignedInt_49(); }

  private native void SetOutputScalarTypeToLong_50();
  public void SetOutputScalarTypeToLong()
    { SetOutputScalarTypeToLong_50(); }

  private native void SetOutputScalarTypeToUnsignedLong_51();
  public void SetOutputScalarTypeToUnsignedLong()
    { SetOutputScalarTypeToUnsignedLong_51(); }

  private native void SetOutputScalarTypeToShort_52();
  public void SetOutputScalarTypeToShort()
    { SetOutputScalarTypeToShort_52(); }

  private native void SetOutputScalarTypeToUnsignedShort_53();
  public void SetOutputScalarTypeToUnsignedShort()
    { SetOutputScalarTypeToUnsignedShort_53(); }

  private native void SetOutputScalarTypeToUnsignedChar_54();
  public void SetOutputScalarTypeToUnsignedChar()
    { SetOutputScalarTypeToUnsignedChar_54(); }

  private native void SetOutputScalarTypeToChar_55();
  public void SetOutputScalarTypeToChar()
    { SetOutputScalarTypeToChar_55(); }

  private native void StartAppend_56();
  public void StartAppend()
    { StartAppend_56(); }

  private native void Append_57(vtkDataSet id0);
  public void Append(vtkDataSet id0)
    { Append_57(id0); }

  private native void EndAppend_58();
  public void EndAppend()
    { EndAppend_58(); }

  public vtkImplicitModeller() { super(); }

  public vtkImplicitModeller(long id) { super(id); }
  public native long   VTKInit();

}
